@@ -8,16 +8,15 @@
 
 #pragma once
 
-#include "kcmoduleinfo.h"
 #include "kontactkcmultidialog_p.h"
 #include "kontactsettingsdialog.h"
+#include <KCModuleInfo>
 
 #include <QHash>
 #include <QSet>
 #include <QString>
 
 #include <KPageWidgetModel>
-#include <KPluginInfo>
 #include <KService>
 
 class KontactSettingsDialogPrivate : public KontactKCMultiDialogPrivate
